@@ -6,9 +6,6 @@ class B(A):
 
   def get_first(self):
     return A.get_first(self) + " world!"
-
-  def process_text(self, string):
-    self.smem = "hello"
     
 
 
@@ -18,11 +15,3 @@ b.get(0)
 if b.get_first() != "hello world!":
   print b.get_first() 
   raise RuntimeError
-
-
-b.call_process_func()
-
-if b.smem != "hello":
-  print smem
-  raise RuntimeError
-  
