@@ -8,19 +8,12 @@
  * Copyright (C) 1999-2000.  The University of Chicago
  * See the file LICENSE for information on usage and redistribution.
  *
- * $Id: doh.h 9631 2007-01-03 05:23:20Z beazley $
+ * $Header: /cvsroot/swig/SWIG/Source/DOH/doh.h,v 1.10 2005/02/15 21:00:52 wsfulton Exp $
  * ----------------------------------------------------------------------------- */
 
 #ifndef _DOH_H
 #define _DOH_H
 
-#ifndef MACSWIG
-#include "swigconfig.h"
-#endif
-
-#include <stdio.h>
-#include <stdarg.h>
-
 /* Set the namespace prefix for DOH API functions. This can be used to control
    visibility of the functions in libraries */
 
@@ -47,9 +40,8 @@
 #define DohLen             DOH_NAMESPACE(Len)
 #define DohHashval         DOH_NAMESPACE(Hashval)
 #define DohCmp             DOH_NAMESPACE(Cmp)
-#define DohEqual           DOH_NAMESPACE(Equal)
 #define DohIncref          DOH_NAMESPACE(Incref)
-#define DohCheckattr       DOH_NAMESPACE(Checkattr)
+#define DohGetattr         DOH_NAMESPACE(Getattr)
 #define DohSetattr         DOH_NAMESPACE(Setattr)
 #define DohDelattr         DOH_NAMESPACE(Delattr)
 #define DohKeys            DOH_NAMESPACE(Keys)
@@ -92,7 +84,6 @@
 #define DohIsString        DOH_NAMESPACE(IsString)
 #define DohIsFile          DOH_NAMESPACE(IsFile)
 #define DohNewString       DOH_NAMESPACE(NewString)
-#define DohNewStringEmpty  DOH_NAMESPACE(NewStringEmpty)
 #define DohNewStringWithSize  DOH_NAMESPACE(NewStringWithSize)
 #define DohNewStringf      DOH_NAMESPACE(NewStringf)
 #define DohStrcmp          DOH_NAMESPACE(Strcmp)
@@ -102,7 +93,6 @@
 #define DohNewFile         DOH_NAMESPACE(NewFile)
 #define DohNewFileFromFile DOH_NAMESPACE(NewFileFromFile)
 #define DohNewFileFromFd   DOH_NAMESPACE(NewFileFromFd)
-#define DohFileErrorDisplay   DOH_NAMESPACE(FileErrorDisplay)
 #define DohClose           DOH_NAMESPACE(Close)
 #define DohCopyto          DOH_NAMESPACE(Copyto)
 #define DohNewList         DOH_NAMESPACE(NewList)
@@ -125,6 +115,9 @@
 #define DohNext            DOH_NAMESPACE(Next)
 #endif
 
+#include <stdio.h>
+#include <stdarg.h>
+
 #define DOH_MAJOR_VERSION 0
 #define DOH_MINOR_VERSION 1
 
@@ -152,11 +145,11 @@ typedef void DOH;
 /* Iterator objects */
 
 typedef struct {
-  void *key;			/* Current key (if any)       */
-  void *item;			/* Current item               */
-  void *object;			/* Object being iterated over */
-  void *_current;		/* Internal use */
-  int _index;			/* Internal use */
+  void   *key;             /* Current key (if any)       */
+  void   *item;            /* Current item               */
+  void   *object;          /* Object being iterated over */
+  void   *_current;        /* Internal use */
+  int    _index;           /* Internal use */
 } DohIterator;
 
 /* Memory management */
@@ -171,113 +164,103 @@ typedef struct {
 #define DohFree free
 #endif
 
-extern int DohCheck(const DOH *ptr);	/* Check if a DOH object */
-extern void DohIntern(DOH *);	/* Intern an object      */
+extern int           DohCheck(const DOH *ptr);           /* Check if a DOH object */
+extern void          DohIntern(DOH *);                   /* Intern an object      */
 
 /* Basic object methods.  Common to most objects */
 
-extern void DohDelete(DOH *obj);	/* Delete an object      */
-extern DOH *DohCopy(const DOH *obj);
-extern void DohClear(DOH *obj);
-extern DOHString *DohStr(const DOH *obj);
-extern void *DohData(const DOH *obj);
-extern int DohDump(const DOH *obj, DOHFile * out);
-extern int DohLen(const DOH *obj);
-extern int DohHashval(const DOH *obj);
-extern int DohCmp(const DOH *obj1, const DOH *obj2);
-extern int DohEqual(const DOH *obj1, const DOH *obj2);
-extern void DohIncref(DOH *obj);
+extern void          DohDelete(DOH *obj);                /* Delete an object      */
+extern DOH          *DohCopy(const DOH *obj);
+extern void          DohClear(DOH *obj);
+extern DOHString    *DohStr(const DOH *obj);
+extern void         *DohData(const DOH *obj);
+extern int           DohDump(const DOH *obj, DOHFile *out);
+extern int           DohLen(const DOH *obj);
+extern int           DohHashval(const DOH *obj);
+extern int           DohCmp(const DOH *obj1, const DOH *obj2);
+extern void          DohIncref(DOH *obj);
 
 /* Mapping methods */
 
-extern DOH *DohGetattr(DOH *obj, const DOHString_or_char *name);
-extern int DohSetattr(DOH *obj, const DOHString_or_char *name, const DOHObj_or_char * value);
-extern int DohDelattr(DOH *obj, const DOHString_or_char *name);
-extern int DohCheckattr(DOH *obj, const DOHString_or_char *name, const DOHString_or_char *value);
-extern DOH *DohKeys(DOH *obj);
-extern int DohGetInt(DOH *obj, const DOHString_or_char *name);
-extern void DohSetInt(DOH *obj, const DOHString_or_char *name, int);
-extern double DohGetDouble(DOH *obj, const DOHString_or_char *name);
-extern void DohSetDouble(DOH *obj, const DOHString_or_char *name, double);
-extern char *DohGetChar(DOH *obj, const DOHString_or_char *name);
-extern void DohSetChar(DOH *obj, const DOH *name, char *value);
-extern void *DohGetFlagAttr(DOH *obj, const DOHString_or_char *name);
-extern int DohGetFlag(DOH *obj, const DOHString_or_char *name);
-extern void DohSetFlagAttr(DOH *obj, const DOHString_or_char *name, const DOHString_or_char *attr);
-extern void DohSetFlag(DOH *obj, const DOHString_or_char *name);
-extern void *DohGetVoid(DOH *obj, const DOHString_or_char *name);
-extern void DohSetVoid(DOH *obj, const DOHString_or_char *name, void *value);
+extern DOH          *DohGetattr(DOH *obj, const DOHString_or_char *name);
+extern int           DohSetattr(DOH *obj, const DOHString_or_char *name, const DOHObj_or_char *value);
+extern int           DohDelattr(DOH *obj, const DOHString_or_char *name);
+extern DOH          *DohKeys(DOH *obj);
+extern int           DohGetInt(DOH *obj, const DOHString_or_char *name);
+extern double        DohGetDouble(DOH *obj, const DOHString_or_char *name);
+extern char         *DohGetChar(DOH *obj, const DOHString_or_char *name);
+extern void          DohSetInt(DOH *obj, const DOHString_or_char *name, int);
+extern void          DohSetDouble(DOH *obj, const DOHString_or_char *name, double);
+extern void         *DohGetVoid(DOH *obj, const DOHString_or_char *name);
+extern void          DohSetVoid(DOH *obj, const DOHString_or_char *name, void *value);
 
 /* Sequence methods */
 
-extern DOH *DohGetitem(DOH *obj, int index);
-extern int DohSetitem(DOH *obj, int index, const DOHObj_or_char * value);
-extern int DohDelitem(DOH *obj, int index);
-extern int DohInsertitem(DOH *obj, int index, const DOHObj_or_char * value);
-extern int DohDelslice(DOH *obj, int sindex, int eindex);
+extern DOH          *DohGetitem(DOH *obj, int index);
+extern int           DohSetitem(DOH *obj, int index, const DOHObj_or_char *value);
+extern int           DohDelitem(DOH *obj, int index);
+extern int           DohInsertitem(DOH *obj, int index, const DOHObj_or_char *value);
+extern int           DohDelslice(DOH *obj, int sindex, int eindex);
 
 /* File methods */
 
-extern int DohWrite(DOHFile * obj, void *buffer, int length);
-extern int DohRead(DOHFile * obj, void *buffer, int length);
-extern int DohSeek(DOHFile * obj, long offset, int whence);
-extern long DohTell(DOHFile * obj);
-extern int DohGetc(DOHFile * obj);
-extern int DohPutc(int ch, DOHFile * obj);
-extern int DohUngetc(int ch, DOHFile * obj);
-
-
+extern int           DohWrite(DOHFile *obj, void *buffer, int length);
+extern int           DohRead(DOHFile *obj, void *buffer, int length);
+extern int           DohSeek(DOHFile *obj, long offset, int whence);
+extern long          DohTell(DOHFile *obj);
+extern int           DohGetc(DOHFile *obj);
+extern int           DohPutc(int ch, DOHFile *obj);
+extern int           DohUngetc(int ch, DOHFile *obj);
 
 /* Iterators */
-extern DohIterator DohFirst(DOH *obj);
-extern DohIterator DohNext(DohIterator x);
+extern DohIterator   DohFirst(DOH *obj);
+extern DohIterator   DohNext(DohIterator x);
 
 /* Positional */
 
-extern int DohGetline(DOH *obj);
-extern void DohSetline(DOH *obj, int line);
-extern DOH *DohGetfile(DOH *obj);
-extern void DohSetfile(DOH *obj, DOH *file);
+extern int           DohGetline(DOH *obj);
+extern void          DohSetline(DOH *obj, int line);
+extern DOH          *DohGetfile(DOH *obj);
+extern void          DohSetfile(DOH *obj, DOH *file);
 
   /* String Methods */
 
-extern int DohReplace(DOHString * src, const DOHString_or_char *token, const DOHString_or_char *rep, int flags);
-extern void DohChop(DOHString * src);
+extern int           DohReplace(DOHString *src, const DOHString_or_char *token, const DOHString_or_char *rep, int flags);
+extern void          DohChop(DOHString *src);
 
 /* Meta-variables */
-extern DOH *DohGetmeta(DOH *, const DOH *);
-extern int DohSetmeta(DOH *, const DOH *, const DOH *value);
-extern int DohDelmeta(DOH *, const DOH *);
+extern DOH          *DohGetmeta(DOH *, const DOH *);
+extern int           DohSetmeta(DOH *, const DOH *, const DOH *value);
+extern int           DohDelmeta(DOH *, const DOH *);
 
   /* Utility functions */
 
-extern void DohEncoding(char *name, DOH *(*fn) (DOH *s));
-extern int DohPrintf(DOHFile * obj, const char *format, ...);
-extern int DohvPrintf(DOHFile * obj, const char *format, va_list ap);
-extern int DohPrintv(DOHFile * obj, ...);
-extern DOH *DohReadline(DOHFile * in);
+extern void          DohEncoding(char *name, DOH *(*fn)(DOH *s));
+extern int           DohPrintf(DOHFile *obj, const char *format, ...);
+extern int           DohvPrintf(DOHFile *obj, const char *format, va_list ap);
+extern int           DohPrintv(DOHFile *obj, ...);
+extern DOH          *DohReadline(DOHFile *in);
 
   /* Miscellaneous */
 
-extern int DohIsMapping(const DOH *obj);
-extern int DohIsSequence(const DOH *obj);
-extern int DohIsString(const DOH *obj);
-extern int DohIsFile(const DOH *obj);
+extern int           DohIsMapping(const DOH *obj);
+extern int           DohIsSequence(const DOH *obj);
+extern int           DohIsString(const DOH *obj);
+extern int           DohIsFile(const DOH *obj);
 
-extern void DohSetmark(DOH *obj, int x);
-extern int DohGetmark(DOH *obj);
+extern void          DohSetmark(DOH *obj, int x);
+extern int           DohGetmark(DOH *obj);
 
 /* -----------------------------------------------------------------------------
  * Strings.
  * ----------------------------------------------------------------------------- */
 
-extern DOHString *DohNewStringEmpty();
-extern DOHString *DohNewString(const DOH *c);
-extern DOHString *DohNewStringWithSize(const DOH *c, int len);
-extern DOHString *DohNewStringf(const DOH *fmt, ...);
+extern DOHString    *DohNewString(const DOH *c);
+extern DOHString    *DohNewStringWithSize(const DOH *c, int len);
+extern DOHString    *DohNewStringf(const DOH *fmt, ...);
 
-extern int DohStrcmp(const DOHString_or_char *s1, const DOHString_or_char *s2);
-extern int DohStrncmp(const DOHString_or_char *s1, const DOHString_or_char *s2, int n);
+extern int   DohStrcmp(const DOHString_or_char *s1, const DOHString_or_char *s2);
+extern int   DohStrncmp(const DOHString_or_char *s1, const DOHString_or_char *s2, int n);
 extern char *DohStrstr(const DOHString_or_char *s1, const DOHString_or_char *s2);
 extern char *DohStrchr(const DOHString_or_char *s1, int ch);
 
@@ -300,34 +283,33 @@ extern char *DohStrchr(const DOHString_or_char *s1, int ch);
 extern DOHFile *DohNewFile(DOH *file, const char *mode);
 extern DOHFile *DohNewFileFromFile(FILE *f);
 extern DOHFile *DohNewFileFromFd(int fd);
-extern void DohFileErrorDisplay(DOHString * filename);
-extern int DohClose(DOH *file);
-extern int DohCopyto(DOHFile * input, DOHFile * output);
+extern int      DohClose(DOH *file);
+extern int      DohCopyto(DOHFile *input, DOHFile *output);
 
 
 /* -----------------------------------------------------------------------------
  * List
  * ----------------------------------------------------------------------------- */
 
-extern DOHList *DohNewList();
-extern void DohSortList(DOH *lo, int (*cmp) (const DOH *, const DOH *));
+extern DOHList  *DohNewList();
+extern void DohSortList(DOH *lo, int (*cmp)(const DOH *, const DOH *));
 
 /* -----------------------------------------------------------------------------
  * Hash
  * ----------------------------------------------------------------------------- */
 
-extern DOHHash *DohNewHash();
+extern DOHHash   *DohNewHash();
 
 /* -----------------------------------------------------------------------------
  * Void
  * ----------------------------------------------------------------------------- */
 
-extern DOHVoid *DohNewVoid(void *ptr, void (*del) (void *));
-extern DOHList *DohSplit(DOHFile * input, char ch, int nsplits);
-extern DOHList *DohSplitLines(DOHFile * input);
-extern DOH *DohNone;
+extern DOHVoid  *DohNewVoid(void *ptr, void (*del)(void *));
+extern DOHList  *DohSplit(DOHFile *input, char ch, int nsplits);
+extern DOHList  *DohSplitLines(DOHFile *input);
+extern DOH      *DohNone;
 
-extern void DohMemoryDebug(void);
+extern void      DohMemoryDebug(void);
 
 #ifndef DOH_LONG_NAMES
 /* Macros to invoke the above functions.  Includes the location of
@@ -341,7 +323,6 @@ extern void DohMemoryDebug(void);
 #define Getattr            DohGetattr
 #define Setattr            DohSetattr
 #define Delattr            DohDelattr
-#define Checkattr          DohCheckattr
 #define Hashval            DohHashval
 #define Getitem            DohGetitem
 #define Setitem            DohSetitem
@@ -354,7 +335,6 @@ extern void DohMemoryDebug(void);
 #define Data               DohData
 #define Char               (char *) Data
 #define Cmp                DohCmp
-#define Equal              DohEqual
 #define Setline            DohSetline
 #define Getline            DohGetline
 #define Setfile            DohSetfile
@@ -368,31 +348,16 @@ extern void DohMemoryDebug(void);
 #define Getc               DohGetc
 #define Putc               DohPutc
 #define Ungetc             DohUngetc
-
-/* #define StringPutc         DohStringPutc */
-/* #define StringGetc         DohStringGetc */
-/* #define StringUngetc       DohStringUngetc */
-/* #define StringAppend       Append */
-/* #define StringLen          DohStringLen */
-/* #define StringChar         DohStringChar */
-/* #define StringEqual        DohStringEqual */
-
 #define Close              DohClose
 #define vPrintf            DohvPrintf
 #define GetInt             DohGetInt
 #define GetDouble          DohGetDouble
 #define GetChar            DohGetChar
 #define GetVoid            DohGetVoid
-#define GetFlagAttr        DohGetFlagAttr
-#define GetFlag            DohGetFlag
 #define SetInt             DohSetInt
 #define SetDouble          DohSetDouble
 #define SetChar            DohSetattr
 #define SetVoid            DohSetVoid
-#define SetFlagAttr        DohSetFlagAttr
-#define SetFlag            DohSetFlag
-#define UnsetFlag(o,n)     DohSetFlagAttr(o,n,NULL)
-#define ClearFlag(o,n)     DohSetFlagAttr(o,n,"")
 #define Readline           DohReadline
 #define Replace            DohReplace
 #define Chop               DohChop
@@ -400,7 +365,6 @@ extern void DohMemoryDebug(void);
 #define Setmeta            DohSetmeta
 #define Delmeta            DohDelmeta
 #define NewString          DohNewString
-#define NewStringEmpty     DohNewStringEmpty
 #define NewStringWithSize  DohNewStringWithSize
 #define NewStringf         DohNewStringf
 #define NewHash            DohNewHash
@@ -408,7 +372,6 @@ extern void DohMemoryDebug(void);
 #define NewFile            DohNewFile
 #define NewFileFromFile    DohNewFileFromFile
 #define NewFileFromFd      DohNewFileFromFd
-#define FileErrorDisplay   DohFileErrorDisplay
 #define Close              DohClose
 #define NewVoid            DohNewVoid
 #define Keys               DohKeys
@@ -436,4 +399,8 @@ extern void DohMemoryDebug(void);
 #define NIL  (char *) NULL
 
 
-#endif				/* DOH_H */
+#endif /* DOH_H */
+
+
+
+
