@@ -9,7 +9,7 @@
  * See the file LICENSE for information on usage and redistribution.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_python_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/python.cxx,v 1.107 2005/10/07 13:17:41 marcelomatus Exp $";
+char cvsroot_python_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/python.cxx,v 1.94 2005/06/03 21:25:00 wsfulton Exp $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -35,10 +35,8 @@ static  File         *f_wrappers = 0;
 static  File         *f_directors = 0;
 static  File         *f_directors_h = 0;
 static  File         *f_init = 0;
-static  File         *f_shadow_py = 0;
-static  String       *f_shadow = 0;
-static  String       *f_shadow_imports = 0;
-static  String       *f_shadow_stubs = 0;
+static  File         *f_shadow = 0;
+static  File         *f_shadow_stubs = 0;
 
 static  String       *methods;
 static  String       *class_name;
@@ -72,8 +70,7 @@ Python Options (available with -python)\n\
      -interface <lib>- Set the lib name to <lib>\n\
      -keyword        - Use keyword arguments\n\
      -classic        - Use classic classes only\n\
-     -nocppcast      - Disable C++ casting operators, useful for generating bugs\n\
-     -cppcast        - Enable C++ casting operators\n\
+     -cppcast        - Enable new C++ casting operators, useful for debugging\n\
      -nortti         - Disable the use of the native C++ RTTI with directors\n\
      -modern         - Use modern python features only, without compatibility code\n\
      -apply          - Use apply() in proxy classes\n\
@@ -107,7 +104,6 @@ public:
    * ------------------------------------------------------------ */
   
   virtual void main(int argc, char *argv[]) {
-    int cppcast = 1;
 
     SWIG_library_directory("python");
   
@@ -157,11 +153,7 @@ public:
 	  Swig_mark_arg(i);
 	} else if (strcmp(argv[i],"-cppcast") == 0) {
 	  /* Turn on new value wrapper mpde */
-	  cppcast = 1;
-	  Swig_mark_arg(i);
-	} else if (strcmp(argv[i],"-nocppcast") == 0) {
-	  /* Turn on new value wrapper mpde */
-	  cppcast = 0;
+	  Preprocessor_define((DOH *) "SWIG_CPLUSPLUS_CAST", 0);
 	  Swig_mark_arg(i);
 	} else if (strcmp(argv[i],"-nortti") == 0) {
 	  /* Turn on no RTTI mode */
@@ -185,12 +177,6 @@ public:
 	}
       }
     }
-
-    if (cppcast) {
-      /* Turn on new value wrapper mpde */
-      Preprocessor_define((DOH *) "SWIG_CPLUSPLUS_CAST", 0);
-    }
-    
     if (!global_name) global_name = NewString("cvar");
     Preprocessor_define("SWIGPYTHON 1", 0);
     SWIG_typemap_lang("python");
@@ -244,7 +230,7 @@ public:
 
     f_runtime = NewFile(outfile,"w");
     if (!f_runtime) {
-      FileErrorDisplay(outfile);
+      Printf(stderr,"*** Can't open '%s'\n", outfile);
       SWIG_exit(EXIT_FAILURE);
     }
     
@@ -252,7 +238,7 @@ public:
       if (!no_header_file) {
 	f_runtime_h = NewFile(outfile_h,"w");
 	if (!f_runtime_h) {
-	  FileErrorDisplay(outfile_h);
+	  Printf(stderr,"*** Can't open '%s'\n", outfile_h);
 	  SWIG_exit(EXIT_FAILURE);
 	}
       } else {
@@ -316,21 +302,19 @@ public:
       // If we don't have an interface then change the module name X to _X
       if (interface) module = interface;
       else Insert(module,0,"_");
-      if ((f_shadow_py = NewFile(filen,"w")) == 0) {
-	FileErrorDisplay(filen);
+      if ((f_shadow = NewFile(filen,"w")) == 0) {
+	Printf(stderr,"Unable to open %s\n", filen);
 	SWIG_exit (EXIT_FAILURE);
       }
       Delete(filen); filen = NULL;
 
-      f_shadow = NewString("");
-      f_shadow_imports = NewString("");
       f_shadow_stubs = NewString("");
 
       Swig_register_filebyname("shadow",f_shadow);
       Swig_register_filebyname("python",f_shadow);
 
-      Printv(f_shadow_py,
-	     "# This file was created automatically by SWIG ", PACKAGE_VERSION, ".\n",
+      Printv(f_shadow,
+	     "# This file was created automatically by SWIG.\n",
 	     "# Don't modify this file, modify the SWIG interface instead.\n",
 	     NIL);
 
@@ -345,6 +329,8 @@ public:
         Delete(mod_docstring); mod_docstring = NULL;
       }
       
+      Printf(f_shadow,"\nimport %s\n\n", module);
+
       /* if (!modern) */
       /* always needed, a class can be forced to be no-modern, such as an exception */
       { 
@@ -404,8 +390,7 @@ public:
         // Try loading weakref.proxy, which is only available in Python 2.1 and higher
         Printv(f_shadow,
                "try:\n",
-	       tab4, "import weakref\n",
-	       tab4, "weakref_proxy = weakref.proxy\n",
+	       tab4, "from weakref import proxy as weakref_proxy\n",
 	       "except:\n",
 	       tab4, "weakref_proxy = lambda x: x\n",
 	       "\n\n",
@@ -446,13 +431,9 @@ public:
     Printf(f_wrappers,"#endif\n");
 
     if (shadow) {
-      Printf(f_shadow_imports,"\nimport %s\n", module);
-      Printv(f_shadow_py, f_shadow_imports, "\n",NIL);
-      Printv(f_shadow_py, f_shadow, "\n",NIL);
-      Printv(f_shadow_py, f_shadow_stubs, "\n",NIL);
-
-      Close(f_shadow_py);
-      Delete(f_shadow_py);
+      Printv(f_shadow, f_shadow_stubs, "\n",NIL);
+      Close(f_shadow);
+      Delete(f_shadow);
     }
 
     /* Close all of the files */
@@ -487,9 +468,8 @@ public:
   virtual int importDirective(Node *n) {
     if (shadow) {
       String *modname = Getattr(n,"module");
-
       if (modname) {
-        String *import = NewString("import ");
+        Printf(f_shadow,"import ");
 
         // Find the module node for this imported module.  It should be the
         // first child but search just in case.
@@ -503,16 +483,11 @@ public:
         Node *options = Getattr(mod, "options");
         String* pkg = options ? Getattr(options, "package") : 0;
 	if (pkg && (!package || Strcmp(pkg, package) != 0)) {
-	  Printf(import, "%s.", pkg);
+	  Printf(f_shadow, "%s.", pkg);
         }
 
         // finally, output the name of the imported module
-	Printf(import, "%s\n", modname);
-
-	if (!Strstr(f_shadow_imports, import)) {
-	  Printf(f_shadow_imports, "%s", import);
-	}
-	Delete(import);
+	Printf(f_shadow, "%s\n", modname);
       }
     }
     return Language::importDirective(n);
@@ -636,7 +611,7 @@ public:
   bool have_docstring(Node *n) {
     String* str = Getattr(n, "feature:docstring");
     return (str != NULL && Len(str) > 0) ||
-        (Getattr(n,"feature:autodoc") && !GetFlag(n, "feature:noautodoc"));
+        (Getattr(n,"feature:autodoc") && !Getattr(n, "feature:noautodoc"));
   }
   
   /* ------------------------------------------------------------
@@ -650,7 +625,7 @@ public:
     bool use_triple = true) {
     String* str = Getattr(n, "feature:docstring");
     bool have_ds = (str != NULL && Len(str) > 0);
-    bool have_auto = (Getattr(n,"feature:autodoc") && !GetFlag(n, "feature:noautodoc"));
+    bool have_auto = (Getattr(n,"feature:autodoc") && !Getattr(n, "feature:noautodoc"));
     const char* triple_double = use_triple ? "\"\"\"" : "";
     String* autodoc = NULL;
     String* doc = NULL;
@@ -1042,7 +1017,7 @@ public:
    * ------------------------------------------------------------ */
 
   int check_kwargs(Node *n) {
-    return (use_kw || GetFlag(n,"feature:kwargs"));
+    return ((use_kw || Getattr(n,"feature:kwargs")) && !Getattr(n, "feature:nokwargs")) ? 1 : 0;
   }
 
 
@@ -1057,7 +1032,7 @@ public:
     else
       Printf(methods,"\t { (char *)\"%s\", (PyCFunction) %s, METH_VARARGS | METH_KEYWORDS, ", name, function);
     
-    if (n && GetFlag(n,"feature:callback")) {
+    if (n && Getattr(n,"feature:callback")) {
       if (have_docstring(n)) {
         String* ds = docstring(n, AUTODOC_FUNC, "", false);
         Replaceall(ds, "\n", "\\n");
@@ -1107,7 +1082,7 @@ public:
     
     Replaceall(dispatch,"$args","self,args");
     Printv(f->code,dispatch,"\n",NIL);
-    if (GetFlag(n,"feature:python:maybecall")) {
+    if (checkAttribute(n,"feature:python:maybecall","1")) {
       Printf(f->code,"Py_INCREF(Py_NotImplemented);\n");
       Printf(f->code,"return Py_NotImplemented;\n");
     } else {
@@ -1445,7 +1420,7 @@ public:
       Replaceall(tm,"$source", "result");
       Replaceall(tm,"$target", "resultobj");
       Replaceall(tm,"$result", "resultobj");
-      if (GetFlag(n,"feature:new")) {
+      if (Getattr(n,"feature:new")) {
 	Replaceall(tm,"$owner","1");
       } else {
 	Replaceall(tm,"$owner","0");
@@ -1493,7 +1468,7 @@ public:
     Printv(f->code,cleanup,NIL);
 
     /* Look to see if there is any newfree cleanup code */
-    if (GetFlag(n,"feature:new")) {
+    if (Getattr(n,"feature:new")) {
       if ((tm = Swig_typemap_lookup_new("newfree",n,"result",0))) {
 	Replaceall(tm,"$source","result");
 	Printf(f->code,"%s\n",tm);
@@ -1954,18 +1929,18 @@ public:
       have_constructor = 0;
       have_repr = 0;
       
-      if (GetFlag(n,"feature:classic")) {
+      if (Getattr(n,"feature:exceptionclass")) {
+	classic = 1;
+        modern  = 0;
+      }
+      if (Getattr(n,"feature:classic")) {
         classic = 1;
         modern  = 0;
       }
-      if (GetFlag(n,"feature:modern")) {
+      if (Getattr(n,"feature:modern")) {
         classic = 0;
         modern = 1;
       }
-      if (GetFlag(n,"feature:exceptionclass")) {
-	classic = 1;
-        modern  = 0;
-      }
 
       shadow_indent = (String *) tab4;
       
@@ -1982,7 +1957,7 @@ public:
 	b = First(baselist);
 	while (b.item) {
 	  String *bname = Getattr(b.item, "python:proxy");
-	  if (!bname || GetFlag(b.item,"feature:ignore")) {
+	  if (!bname || Getattr(b.item,"feature:ignore")) {
 	    b = Next(b);
 	    continue;
 	  }
@@ -2014,7 +1989,7 @@ public:
           Printf(f_shadow,"%sfor _s in [%s]: __swig_setmethods__.update(_s.__swig_setmethods__)\n",tab4,base_class);
         }
 
-	if (!GetFlag(n,"feature:python:nondynamic")) {
+	if (!checkAttribute(n,"feature:python:nondynamic","1")) {
 	  Printv(f_shadow,
 		 tab4, "__setattr__ = lambda self, name, value: _swig_setattr(self, ", class_name, ", name, value)\n",
 		 NIL);
@@ -2034,7 +2009,7 @@ public:
                NIL);
       } else {
 	/* Add static attribute */
-	if (GetFlag(n,"feature:python:nondynamic")) {
+	if (checkAttribute(n,"feature:python:nondynamic","1")) {
 	  Printv(f_shadow_file,
 		 tab4, "__setattr__ = _swig_setattr_nondynamic_method(object.__setattr__)\n",
 		 tab4, "class __metaclass__(type):\n",
@@ -2118,7 +2093,8 @@ public:
         Printv(f_shadow_file,
                tab8, "_swig_setattr(self, ", class_name, ", 'this', this)\n",
                tab8, "if not hasattr(self,\"thisown\"): _swig_setattr(self, ", class_name, ", 'thisown', 0)\n",
-	       tab8, "self.__class__ = ", class_name, "\n", NIL);
+               tab8, "_swig_setattr(self, ", class_name, ",self.__class__,", class_name, ")\n",
+               NIL);
       } else {
         Printv(f_shadow_file,
                tab8, "self.this = this\n",
@@ -2147,12 +2123,16 @@ public:
    * ------------------------------------------------------------ */
 
   virtual int functionHandler(Node *n) {
-    String *pcb = GetFlagAttr(n,"feature:python:callback");
+    String *pcb = Getattr(n,"feature:python:callback");
+    if (pcb && (Strcmp(pcb,"0") == 0)) {
+      Setattr(n,"feature:python:callback","");
+      pcb = 0;
+    }
     if (pcb) {
       if (Strcmp(pcb,"1") == 0) {
-	SetFlagAttr(n,"feature:callback","%s_cb_ptr");
+	Setattr(n,"feature:callback","%s_cb_ptr");
       } else {
-	SetFlagAttr(n,"feature:callback",pcb);
+	Setattr(n,"feature:callback",pcb);
       }
       autodoc_l dlevel = autodoc_level(Getattr(n, "feature:autodoc"));
       if (dlevel != NO_AUTODOC && dlevel > TYPES_AUTODOC) {
@@ -2640,6 +2620,8 @@ int PYTHON::classDirectorMethod(Node *n, Node *parent, String *super) {
   Swig_typemap_attach_parms("directorargout", l, w);
 
   Parm* p;
+  int num_arguments = emit_num_arguments(l);
+  int i;
   char source[256];
 
   wrap_args = NewString("");
@@ -2647,9 +2629,8 @@ int PYTHON::classDirectorMethod(Node *n, Node *parent, String *super) {
   if (!is_void) outputs++;
 	
   /* build argument list and type conversion string */
-  idx = 0;
-  p = l;
-  while (p != NULL) {
+  for (i=0, idx=0, p = l; i < num_arguments && p != 0; i++) {
+
     if (checkAttribute(p,"tmap:in:numinputs","0")) {
       p = Getattr(p,"tmap:in:next");
       continue;
@@ -2770,9 +2751,7 @@ int PYTHON::classDirectorMethod(Node *n, Node *parent, String *super) {
     Wrapper_add_localv(w, "c_result", SwigType_lstr(return_type, "c_result"), NIL);
   }
   /* declare Python return value */
-  if (!is_void) {
-    Wrapper_add_local(w, "result", "PyObject *result");
-  }
+  Wrapper_add_local(w, "result", "PyObject *result");
 
   /* direct call to superclass if _up is set */
   Printf(w->code, "if (swig_get_up()) {\n");
@@ -2802,13 +2781,11 @@ int PYTHON::classDirectorMethod(Node *n, Node *parent, String *super) {
   Printf(w->code, "  Swig::DirectorException::raise(\"'self' unitialized, maybe you forgot to call %s.__init__.\");\n", classname);
   Printf(w->code, "}\n");  
   if (Len(parse_args) > 0) {
-    Printf(w->code, "%s PyObject_CallMethod(swig_get_self(), (char *)\"%s\", (char *)\"(%s)\" %s);\n", (!is_void ? "result =" : "(void)"), pyname, parse_args, arglist);
+    Printf(w->code, "result = PyObject_CallMethod(swig_get_self(), (char *)\"%s\", (char *)\"(%s)\" %s);\n", pyname, parse_args, arglist);
   } else {
-    Printf(w->code, "%s PyObject_CallMethod(swig_get_self(), (char *)\"%s\", NULL);\n", (!is_void ? "result =" : "(void)"), pyname);
-  }
-  if (!is_void) {
-    Printv(xdecref, "Py_XDECREF(result);\n", NULL);
+    Printf(w->code, "result = PyObject_CallMethod(swig_get_self(), (char *)\"%s\", NULL);\n", pyname);
   }
+  Printv(xdecref, "Py_XDECREF(result);\n", NULL);
   if (dirprot_mode() && !is_public(n))
     Printf(w->code, "swig_set_inner(\"%s\", false);\n", name);
 
@@ -2817,9 +2794,7 @@ int PYTHON::classDirectorMethod(Node *n, Node *parent, String *super) {
   if (!tm) {
     tm = Getattr(n, "feature:director:except");
   }
-  if (!is_void) {
-    Printf(w->code, "if (result == NULL) {\n");
-  }
+  Printf(w->code, "if (result == NULL) {\n");
   Printf(w->code, "  PyObject *error = PyErr_Occurred();\n");
   if ((tm) && Len(tm) && (Strcmp(tm, "1") != 0)) {
     Replaceall(tm, "$error", "error");
@@ -2831,9 +2806,7 @@ int PYTHON::classDirectorMethod(Node *n, Node *parent, String *super) {
     Printf(w->code, "  }\n");
   }
   
-  if (!is_void) {
-    Printf(w->code, "}\n");
-  }
+  Printf(w->code, "}\n");
 
   /*
    * Python method may return a simple object, or a tuple.
