@@ -1,14 +1,17 @@
 /* ----------------------------------------------------------------------------- 
- * See the LICENSE file for information on copyright, usage and redistribution
- * of SWIG, and the README file for authors - http://www.swig.org/release.html.
- *
  * s-exp.cxx
  *
- * A parse tree represented as Lisp s-expressions.
+ *     A parse tree represented as Lisp s-expressions.
+ * 
+ * Author(s) : Matthias Koeppe (mkoeppe@mail.math.uni-magdeburg.de)
+ *
+ * Copyright (C) 2002.  The University of Chicago
+ * See the file LICENSE for information on usage and redistribution.	
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_s_exp_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/s-exp.cxx,v 1.17 2006/03/06 22:50:59 wsfulton Exp $";
+/* Derived from xml.cxx 1.1.2.2 */
 
+char cvsroot_s_exp_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/s-exp.cxx,v 1.14 2005/02/15 23:04:08 wsfulton Exp $";
 static const char *usage = "\
 S-Exp Options (available with -sexp)\n\
      -typemaplang <lang> - Typemap language\n\n";
@@ -63,16 +66,10 @@ public:
 	out = NewFile(outfile,"w");
 	if (!out) 
 	  {
-	    FileErrorDisplay(outfile);
+	    Printf(stderr,"*** Can't open '%s'\n", outfile);
 	    SWIG_exit(EXIT_FAILURE);
 	  }
       }
-    String *f_sink = NewString("");
-    Swig_register_filebyname("header",f_sink);
-    Swig_register_filebyname("wrapper",f_sink);
-    Swig_register_filebyname("runtime",f_sink);
-    Swig_register_filebyname("init",f_sink);
-    
     Language::top(n);
     Printf( out, ";;; Lisp parse tree produced by SWIG\n" );
     print_circle_hash = DohNewHash();
