@@ -1,16 +1,25 @@
 /* -----------------------------------------------------------------------------
- * See the LICENSE file for information on copyright, usage and redistribution
- * of SWIG, and the README file for authors - http://www.swig.org/release.html.
- *
  * swigmod.h
  *
- * Main header file for SWIG modules.
+ *     Main header file for SWIG modules
+ *
+ * Author(s) : David Beazley (beazley@cs.uchicago.edu)
+ *
+ * Copyright (C) 1998-2000.  The University of Chicago
+ * Copyright (C) 1995-1998.  The University of Utah and The Regents of the
+ *                           University of California.
+ *
+ * See the file LICENSE for information on usage and redistribution.
+ *
+ * $Header: /cvsroot/swig/SWIG/Source/Modules/swigmod.h,v 1.37 2005/04/01 19:43:47 wsfulton Exp $
  * ----------------------------------------------------------------------------- */
 
-/* $Id: swigmod.h 11470 2009-07-29 20:50:39Z wsfulton $ */
+#ifndef SWIGMOD_H_
+#define SWIGMOD_H_
 
-#ifndef SWIG_SWIGMOD_H_
-#define SWIG_SWIGMOD_H_
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
 
 #include "swig.h"
 #include "preprocessor.h"
@@ -26,18 +35,18 @@ typedef int bool;
 #define PLAIN_VIRTUAL   1
 #define PURE_VIRTUAL    2
 
-extern String *input_file;
-extern int line_number;
-extern int start_line;
-extern int CPlusPlus;		// C++ mode
-extern int Extend;		// Extend mode
-extern int Verbose;
-extern int IsVirtual;
-extern int ImportMode;
-extern int NoExcept;		// -no_except option
-extern int Abstract;		// abstract base class
-extern int SmartPointer;	// smart pointer methods being emitted
-extern int SwigRuntime;
+extern  char     *input_file;
+extern  int       line_number;
+extern  int       start_line;
+extern  int       CPlusPlus;                        // C++ mode
+extern  int       Extend;                           // Extend mode
+extern  int       Verbose;
+extern  int       IsVirtual;
+extern  int       ImportMode;
+extern  int       NoExcept;                         // -no_except option
+extern  int       Abstract;                         // abstract base class
+extern  int       SmartPointer;                     // smart pointer methods being emitted
+extern  int       SwigRuntime;
 
 /* Overload "argc" and "argv" */
 extern String *argv_template_string;
@@ -50,20 +59,18 @@ extern String *argc_template_string;
 #define  tab8   "        "
 
 class Dispatcher {
-public:
+ public:
 
-  Dispatcher ():cplus_mode(PUBLIC) {
-  }
-  virtual ~ Dispatcher () {
-  }
+  Dispatcher() : cplus_mode(PUBLIC) {}
+  virtual ~Dispatcher() {}
 
   virtual int emit_one(Node *n);
   virtual int emit_children(Node *n);
   virtual int defaultHandler(Node *n);
 
   /* Top of the parse tree */
-  virtual int top(Node *n) = 0;
-
+  virtual int  top(Node *n) = 0;
+  
   /* SWIG directives */
 
   virtual int applyDirective(Node *n);
@@ -83,7 +90,7 @@ public:
   virtual int typesDirective(Node *n);
 
   /* C/C++ parsing */
-
+  
   virtual int cDeclaration(Node *n);
   virtual int externDeclaration(Node *n);
   virtual int enumDeclaration(Node *n);
@@ -104,15 +111,15 @@ protected:
   AccessMode cplus_mode;
 };
 
-/* ----------------------------------------------------------------------------
+/************************************************************************
  * class language:
  *
  * This class defines the functions that need to be supported by the
  * scripting language being used.    The translator calls these virtual
  * functions to output different types of code for different languages.
- * ------------------------------------------------------------------------- */
+ *************************************************************************/
 
-class Language:public Dispatcher {
+class Language : public Dispatcher {
 public:
   Language();
   virtual ~Language();
@@ -124,10 +131,10 @@ public:
 
   /* Top of the parse tree */
 
-  virtual int top(Node *n);
-
+  virtual int  top(Node *n);
+  
   /* SWIG directives */
-
+  
 
   virtual int applyDirective(Node *n);
   virtual int clearDirective(Node *n);
@@ -145,7 +152,7 @@ public:
   virtual int typesDirective(Node *n);
 
   /* C/C++ parsing */
-
+  
   virtual int cDeclaration(Node *n);
   virtual int externDeclaration(Node *n);
   virtual int enumDeclaration(Node *n);
@@ -197,7 +204,12 @@ public:
   virtual int classDirector(Node *n);
   virtual int classDirectorInit(Node *n);
   virtual int classDirectorEnd(Node *n);
-  virtual int unrollVirtualMethods(Node *n, Node *parent, List *vm, int default_director, int &virtual_destructor, int protectedbase = 0);
+  virtual int unrollVirtualMethods(Node *n, 
+                                   Node *parent, 
+                                   Hash *vm, 
+                                   int default_director, 
+                                   int &virtual_destructor,
+				   int protectedbase = 0);
   virtual int classDirectorConstructor(Node *n);
   virtual int classDirectorDefaultConstructor(Node *n);
   virtual int classDirectorMethod(Node *n, Node *parent, String *super);
@@ -207,23 +219,16 @@ public:
   virtual int classDirectorDisown(Node *n);
 
   /* Miscellaneous */
-  virtual int validIdentifier(String *s);	/* valid identifier? */
-  virtual int addSymbol(const String *s, const Node *n);	/* Add symbol        */
-  virtual Node *symbolLookup(String *s);	/* Symbol lookup     */
-  virtual Node *classLookup(SwigType *s);	/* Class lookup      */
-  virtual Node *enumLookup(SwigType *s);	/* Enum lookup       */
-  virtual int abstractClassTest(Node *n);	/* Is class really abstract? */
-  virtual int is_assignable(Node *n);	/* Is variable assignable? */
-  virtual String *runtimeCode();	/* returns the language specific runtime code */
-  virtual String *defaultExternalRuntimeFilename();	/* the default filename for the external runtime */
-  virtual void replaceSpecialVariables(String *method, String *tm, Parm *parm); /* Language specific special variable substitutions for $typemap() */
-
-  /* Runtime is C++ based, so extern "C" header section */
-  void enable_cplus_runtime_mode();
-
-  /* Returns the cplus_runtime mode */
-  int cplus_runtime_mode();
-
+  virtual  int  validIdentifier(String *s);                 /* valid identifier? */
+  virtual  int  addSymbol(const String *s, const Node *n);  /* Add symbol        */
+  virtual  Node *symbolLookup(String *s);                   /* Symbol lookup     */
+  virtual  Node *classLookup(SwigType *s);                  /* Class lookup      */
+  virtual  Node *enumLookup(SwigType *s);                   /* Enum lookup       */
+  virtual  int  abstractClassTest(Node *n);	            /* Is class really abstract? */
+  virtual  int  is_assignable(Node *n);	                   /* Is variable assignable? */
+  virtual  String *runtimeCode();                          /* returns the language specific runtime code */
+  virtual  String *defaultExternalRuntimeFilename();       /* the default filename for the external runtime */
+  
   /* Allow director related code generation */
   void allow_directors(int val = 1);
 
@@ -231,13 +236,10 @@ public:
   int directorsEnabled() const;
 
   /* Allow director protected members related code generation */
-  void allow_dirprot(int val = 1);
-
-  /* Allow all protected members code generation (for directors) */
-  void allow_allprotected(int val = 0);
+  void allow_dirprot(int val = 1);  
 
   /* Returns the dirprot mode */
-  int dirprot_mode() const;
+  int dirprot_mode() const;  
 
   /* Check if the non public constructor is  needed (for directors) */
   int need_nonpublic_ctor(Node *n);
@@ -251,15 +253,12 @@ public:
   /* Set overload variable templates argc and argv */
   void setOverloadResolutionTemplates(String *argc, String *argv);
 
-  /* Language instance is a singleton - get instance */
-  static Language* instance();
-
 protected:
   /* Allow multiple-input typemaps */
-  void allow_multiple_input(int val = 1);
+  void   allow_multiple_input(int val = 1);
 
   /* Allow overloaded functions */
-  void allow_overloading(int val = 1);
+  void   allow_overloading(int val = 1);
 
   /* Wrapping class query */
   int is_wrapping_class();
@@ -273,9 +272,6 @@ protected:
   /* Return the real name of the current class */
   String *getClassName() const;
 
-  /* Return the classes hash */
-  Hash *getClassHash() const;
-
   /* Return the current class prefix */
   String *getClassPrefix() const;
 
@@ -285,16 +281,13 @@ protected:
   /* Return true if the current method is part of a smart-pointer */
   int is_smart_pointer() const;
 
-  /* Some language modules require additional wrappers for virtual methods not declared in sub-classes */
-  virtual bool extraDirectorProtectedCPPMethodsRequired() const;
-
   /* Director subclass comparison test */
   String *none_comparison;
 
   /* Director constructor "template" code */
   String *director_ctor_code;
 
-  /* Director 'protected' constructor "template" code */
+  /* Director 'protected' constructor "template" code*/
   String *director_prot_ctor_code;
 
   /* Director allows multiple inheritance */
@@ -304,74 +297,59 @@ protected:
   int director_language;
 
 private:
-  Hash *symbols;
-  Hash *classtypes;
-  Hash *enumtypes;
-  int overloading;
-  int multiinput;
-  int cplus_runtime;
-  int directors;
-  static Language *this_;
+  Hash   *symbols;
+  Hash   *classtypes;
+  Hash   *enumtypes;
+  int     overloading;
+  int     multiinput;
+  int     directors;
 };
 
-int SWIG_main(int, char **, Language *);
-void emit_parameter_variables(ParmList *l, Wrapper *f);
-void emit_return_variable(Node *n, SwigType *rt, Wrapper *f);
-void SWIG_exit(int);		/* use EXIT_{SUCCESS,FAILURE} */
-void SWIG_config_file(const_String_or_char_ptr );
+int   SWIG_main(int, char **, Language *);
+void  emit_args(SwigType *, ParmList *, Wrapper *f);
+void  SWIG_exit(int);           /* use EXIT_{SUCCESS,FAILURE} */
+void  SWIG_config_file(const String_or_char *);
 const String *SWIG_output_directory();
-void SWIG_config_cppext(const char *ext);
+void  SWIG_config_cppext(const char *ext);
 
-/* get the list of generated files */
-List *SWIG_output_files();
-
-void SWIG_library_directory(const char *);
-int emit_num_arguments(ParmList *);
-int emit_num_required(ParmList *);
-int emit_isvarargs(ParmList *);
-void emit_attach_parmmaps(ParmList *, Wrapper *f);
-void emit_mark_varargs(ParmList *l);
-String *emit_action(Node *n);
-int emit_action_code(Node *n, String *wrappercode, String *action);
-void Swig_overload_check(Node *n);
-String *Swig_overload_dispatch(Node *n, const_String_or_char_ptr fmt, int *);
-String *Swig_overload_dispatch_cast(Node *n, const_String_or_char_ptr fmt, int *);
-String *Swig_overload_dispatch_fast(Node *n, const_String_or_char_ptr fmt, int *);
+void   SWIG_library_directory(const char *);
+int    emit_num_arguments(ParmList *);
+int    emit_num_required(ParmList *);
+int    emit_isvarargs(ParmList *);
+void   emit_attach_parmmaps(ParmList *, Wrapper *f);
+void   emit_mark_varargs(ParmList *l);
+void   emit_action(Node *n, Wrapper *f);
+void   Swig_overload_check(Node *n);
+String *Swig_overload_dispatch(Node *n, const String_or_char *fmt, int *);
 SwigType *cplus_value_type(SwigType *t);
 
 /* directors.cxx start */
-String *Swig_csuperclass_call(String *base, String *method, ParmList *l);
+String *Swig_csuperclass_call(String* base, String* method, ParmList* l);
 String *Swig_class_declaration(Node *n, String *name);
 String *Swig_class_name(Node *n);
-String *Swig_method_call(const_String_or_char_ptr name, ParmList *parms);
-String *Swig_method_decl(SwigType *rtype, SwigType *decl, const_String_or_char_ptr id, List *args, int strip, int values);
+String *Swig_method_call(String_or_char *name, ParmList *parms);
+String *Swig_method_decl(SwigType *s, const String_or_char *id, List *args, int strip, int values);
 String *Swig_director_declaration(Node *n);
-void Swig_director_emit_dynamic_cast(Node *n, Wrapper *f);
 /* directors.cxx end */
 
 extern "C" {
-  void SWIG_typemap_lang(const char *);
-  typedef Language *(*ModuleFactory) (void);
-} 
+  void  SWIG_typemap_lang(const char *);
+  typedef Language *(*ModuleFactory)(void);
+}
 
-void Swig_register_module(const char *name, ModuleFactory fac);
+void   Swig_register_module(const char *name, ModuleFactory fac);
 ModuleFactory Swig_find_module(const char *name);
 
 /* Utilities */
 
-int is_public(Node *n);
-int is_private(Node *n);
-int is_protected(Node *n);
-int is_member_director(Node *parentnode, Node *member);
-int is_member_director(Node *member);
-int is_non_virtual_protected_access(Node *n); /* Check if the non-virtual protected members are required (for directors) */
-int use_naturalvar_mode(Node *n);
-
+int is_public(Node* n); 
+int is_private(Node* n); 
+int is_protected(Node* n); 
+int is_member_director(Node* parentnode, Node* member); 
+int is_member_director(Node* member); 
 void Wrapper_virtual_elimination_mode_set(int);
-void Wrapper_fast_dispatch_mode_set(int);
-void Wrapper_cast_dispatch_mode_set(int);
-void Wrapper_naturalvar_mode_set(int);
-
+void Wrapper_director_mode_set(int);
+void Wrapper_director_protected_mode_set(int);
 
 void clean_overloaded(Node *n);
 
@@ -379,7 +357,7 @@ void clean_overloaded(Node *n);
 
 void Swig_contracts(Node *n);
 void Swig_contract_mode_set(int flag);
-int Swig_contract_mode_get();
+int  Swig_contract_mode_get();
 
 /* Browser */
 
@@ -389,3 +367,7 @@ void Swig_process_types(Node *n);
 
 
 #endif
+
+
+
+
