@@ -1,23 +1,20 @@
 /* -----------------------------------------------------------------------------
- * See the LICENSE file for information on copyright, usage and redistribution
- * of SWIG, and the README file for authors - http://www.swig.org/release.html.
- *
  * typemap.c
  *
- * A somewhat generalized implementation of SWIG1.1 typemaps.
+ *     A somewhat generalized implementation of SWIG1.1 typemaps.
+ *
+ * Author(s) : David Beazley (beazley@cs.uchicago.edu)
+ *
+ * Copyright (C) 1999-2000.  The University of Chicago
+ * See the file LICENSE for information on usage and redistribution.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typemap_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typemap.c,v 1.70 2006/03/06 22:51:00 wsfulton Exp $";
+char cvsroot_typemap_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typemap.c,v 1.48 2005/03/14 23:25:04 marcelomatus Exp $";
 
 #include "swig.h"
-#include "swigkeys.h"
 #include "cparse.h"
 #include <ctype.h>
 
-#if 0
-#define SWIG_DEBUG 
-#endif
-
 static void replace_embedded_typemap(String *s);
 
 /* -----------------------------------------------------------------------------
@@ -61,19 +58,7 @@ static Hash* get_typemap(int tm_scope, SwigType* type)
     Delete(ty);
   }
   tm = Getattr(typemaps[tm_scope],type);
-
-  
-  if (dtype) {
-    if (!tm) {
-      String *t_name = SwigType_templateprefix(type);
-      if (!Equal(t_name,type)) {
-	tm = Getattr(typemaps[tm_scope],t_name);
-      }
-      Delete(t_name);
-    }    
-    Delete(dtype);
-  }
-  
+  Delete(dtype);
   return tm;
 }
 
@@ -181,8 +166,8 @@ Swig_typemap_register(const String_or_char *op, ParmList *parms, String_or_char
 
   /* Register the first type in the parameter list */
 
-  type = Getattr(parms,k_type);
-  pname = Getattr(parms,k_name);
+  type = Getattr(parms,"type");
+  pname = Getattr(parms,"name");
 
   /* See if this type has been seen before */
   tm = get_typemap(tm_scope,type);
@@ -249,14 +234,14 @@ Swig_typemap_register(const String_or_char *op, ParmList *parms, String_or_char
     ParmList *clocals = CopyParmList(locals);
     ParmList *ckwargs = CopyParmList(kwargs);
     
-    Setattr(tm2,k_code, code);
-    Setattr(tm2,k_type, type);
-    Setattr(tm2,k_typemap, typemap);
+    Setattr(tm2,"code", code);
+    Setattr(tm2,"type", type);
+    Setattr(tm2,"typemap", typemap);
     if (pname) {
-      Setattr(tm2,k_pname, pname);
+      Setattr(tm2,"pname", pname);
     }
-    Setattr(tm2,k_locals, clocals);
-    Setattr(tm2,k_kwargs, ckwargs);
+    Setattr(tm2,"locals", clocals);
+    Setattr(tm2,"kwargs", ckwargs);
 
     Delete(clocals);
     Delete(ckwargs);
@@ -310,8 +295,8 @@ Swig_typemap_copy(const String_or_char *op, ParmList *srcparms, ParmList *parms)
     p = srcparms;
     tmops = NewString(tmop);
     while (p) {
-      ptype = Getattr(p,k_type);
-      pname = Getattr(p,k_name);
+      ptype = Getattr(p,"type");
+      pname = Getattr(p,"name");
       
       /* Lookup the type */
       tm = Swig_typemap_get(ptype,pname,ts);
@@ -331,7 +316,7 @@ Swig_typemap_copy(const String_or_char *op, ParmList *srcparms, ParmList *parms)
     if (!p && tm) {
 
       /* Got some kind of match */
-      Swig_typemap_register(op,parms, Getattr(tm,k_code), Getattr(tm,k_locals),Getattr(tm,k_kwargs));
+      Swig_typemap_register(op,parms, Getattr(tm,"code"), Getattr(tm,"locals"),Getattr(tm,"kwargs"));
       return 0;
     }
     ts--;
@@ -359,8 +344,8 @@ Swig_typemap_clear(const String_or_char *op, ParmList *parms) {
   newop = NewString(op);
   p = parms;
   while (p) {
-    type = Getattr(p,k_type);
-    name = Getattr(p,k_name);
+    type = Getattr(p,"type");
+    name = Getattr(p,"name");
     tm = Swig_typemap_get(type,name,tm_scope);
     if (!tm) return;
     p = nextSibling(p);
@@ -370,9 +355,9 @@ Swig_typemap_clear(const String_or_char *op, ParmList *parms) {
   if (tm) {
     tm = Getattr(tm, tmop_name(newop));
     if (tm) {
-      Delattr(tm,k_code);
-      Delattr(tm,k_locals);
-      Delattr(tm,k_kwargs);
+      Delattr(tm,"code");
+      Delattr(tm,"locals");
+      Delattr(tm,"kwargs");
     }
   }
   Delete(newop);
@@ -410,8 +395,8 @@ Swig_typemap_apply(ParmList *src, ParmList *dest) {
   /*  Printf(stdout,"apply : %s --> %s\n", ParmList_str(src), ParmList_str(dest)); */
 
   /* Create type signature of source */
-  ssig = NewStringEmpty();
-  dsig = NewStringEmpty();
+  ssig = NewString("");
+  dsig = NewString("");
   p = src;
   dp = dest;
   lastp = 0;
@@ -420,8 +405,8 @@ Swig_typemap_apply(ParmList *src, ParmList *dest) {
     lastdp = dp;
     np = nextSibling(p);
     if (np) {
-      Printf(ssig,"-%s+%s:", Getattr(p,k_type), Getattr(p,k_name));
-      Printf(dsig,"-%s+%s:", Getattr(dp,k_type), Getattr(dp,k_name));
+      Printf(ssig,"-%s+%s:", Getattr(p,"type"), Getattr(p,"name"));
+      Printf(dsig,"-%s+%s:", Getattr(dp,"type"), Getattr(dp,"name"));
       narg++;
     }
     p = np;
@@ -429,14 +414,14 @@ Swig_typemap_apply(ParmList *src, ParmList *dest) {
   }
 
   /* make sure a typemap node exists for the last destination node */
-  type = Getattr(lastdp,k_type);
+  type = Getattr(lastdp,"type");
   tm = get_typemap(tm_scope,type);
   if (!tm) {
     tm = NewHash();
     set_typemap(tm_scope,type,tm);
     Delete(tm);
   }
-  name = Getattr(lastdp,k_name);
+  name = Getattr(lastdp,"name");
   if (name) {
     Hash *tm1 = Getattr(tm,name);
     if (!tm1) {
@@ -450,8 +435,8 @@ Swig_typemap_apply(ParmList *src, ParmList *dest) {
   /* This is a little nasty.  We need to go searching for all possible typemaps in the
      source and apply them to the target */
 
-  type = Getattr(lastp,k_type);
-  name = Getattr(lastp,k_name);
+  type = Getattr(lastp,"type");
+  name = Getattr(lastp,"name");
 
   while (ts >= 0) {
 
@@ -488,15 +473,15 @@ Swig_typemap_apply(ParmList *src, ParmList *dest) {
 	  /* Make sure the typemap doesn't already exist in the target map */
 	  
 	  oldm = Getattr(tm,nkey);
-	  if (!oldm || (!Getattr(tm,k_code))) {
+	  if (!oldm || (!Getattr(tm,"code"))) {
 	    String *code;
 	    ParmList *locals;
 	    ParmList *kwargs;
 	    Hash *sm1 = ki.item;
 
-	    code = Getattr(sm1,k_code);
-	    locals = Getattr(sm1,k_locals);
-	    kwargs = Getattr(sm1,k_kwargs);
+	    code = Getattr(sm1,"code");
+	    locals = Getattr(sm1,"locals");
+	    kwargs = Getattr(sm1,"kwargs");
 	    if (code) {
 	      Replace(nkey,dsig,"", DOH_REPLACE_ANY);
 	      Replace(nkey,"tmap:","", DOH_REPLACE_ANY);
@@ -530,36 +515,35 @@ Swig_typemap_clear_apply(Parm *parms) {
   String *name;
 
   /* Create a type signature of the parameters */
-  tsig = NewStringEmpty();
+  tsig = NewString("");
   p = parms;
   lastp = 0;
   while (p) {
     lastp = p;
     np = nextSibling(p);
     if (np) {
-      Printf(tsig,"-%s+%s:", Getattr(p,k_type), Getattr(p,k_name));
+      Printf(tsig,"-%s+%s:", Getattr(p,"type"), Getattr(p,"name"));
       narg++;
     }
     p = np;
   }
-  tm = get_typemap(tm_scope,Getattr(lastp,k_type));
+  tm = get_typemap(tm_scope,Getattr(lastp,"type"));
   if (!tm) {
     Delete(tsig);
     return;
   }
-  name = Getattr(lastp,k_name);
+  name = Getattr(lastp,"name");
   if (name) {
     tm = Getattr(tm,name);
   }
   if (tm) {
     /* Clear typemaps that match our signature */
     Iterator ki, ki2;
-    char *ctsig = Char(tsig);
+
     for (ki = First(tm); ki.key; ki = Next(ki)) {
-      char *ckey = Char(ki.key);
-      if (strncmp(ckey,"tmap:",5) == 0) {
+      if (Strncmp(ki.key,"tmap:",5) == 0) {
 	int na = count_args(ki.key);
-	if ((na == narg) && strstr(ckey,ctsig)) {
+	if ((na == narg) && Strstr(ki.key,tsig)) {
 	  Hash *h = ki.item;
 	  for (ki2 = First(h); ki2.key; ki2 = Next(ki2)) {
 	    Delattr(h,ki2.key);
@@ -616,13 +600,13 @@ Swig_typemap_search(const String_or_char *op, SwigType *type, const String_or_ch
 	tm1 = Getattr(tm,cname);
 	if (tm1) {
 	  result = Getattr(tm1,tmop);          /* See if there is a type-name match */
-	  if (result && Getattr(result,k_code)) goto ret_result;
+	  if (result && Getattr(result,"code")) goto ret_result;
 	  if (result) backup = result;
 	}
       }
       if (tm) {
 	result = Getattr(tm,tmop);            /* See if there is simply a type match */
-	if (result && Getattr(result,k_code)) goto ret_result;
+	if (result && Getattr(result,"code")) goto ret_result;
 	if (result) backup = result;
       }
       isarray = SwigType_isarray(ctype);
@@ -637,13 +621,13 @@ Swig_typemap_search(const String_or_char *op, SwigType *type, const String_or_ch
 	  tm1 = Getattr(tma,cname);
 	  if (tm1) {
 	    result = Getattr(tm1,tmop);       /* type-name match */
-	    if (result && Getattr(result,k_code)) goto ret_result;
+	    if (result && Getattr(result,"code")) goto ret_result;
 	    if (result) backup = result;
 	  }
 	}
 	if (tma) {
 	  result = Getattr(tma,tmop);        /* type match */
-	  if (result && Getattr(result,k_code)) goto ret_result;
+	  if (result && Getattr(result,"code")) goto ret_result;
 	  if (result) backup = result;
 	}
 	Delete(noarrays);
@@ -656,7 +640,7 @@ Swig_typemap_search(const String_or_char *op, SwigType *type, const String_or_ch
       if (!unstripped) {
 	unstripped = ctype;
 	ctype = SwigType_strip_qualifiers(ctype);
-	if (!StringEqual(ctype,unstripped)) continue;    /* Types are different */
+	if (Strcmp(ctype,unstripped) != 0) continue;    /* Types are different */
 	Delete(ctype);
 	ctype = unstripped;
 	unstripped = 0;
@@ -731,20 +715,20 @@ Swig_typemap_search_multi(const String_or_char *op, ParmList *parms, int *nmatch
     *nmatch = 0;
     return 0;
   }
-  type = Getattr(parms,k_type);
-  name = Getattr(parms,k_name);
+  type = Getattr(parms,"type");
+  name = Getattr(parms,"name");
 
   /* Try to find a match on the first type */
   tm = Swig_typemap_search(op, type, name, &mtype);
   if (tm) {
     if (mtype && SwigType_isarray(mtype)) {
-      Setattr(parms,k_tmapmatch, mtype);
+      Setattr(parms,"tmap:match", mtype);
     }
     Delete(mtype);
     newop = NewStringf("%s-%s+%s:", op, type,name);
     tm1 = Swig_typemap_search_multi(newop, nextSibling(parms), nmatch);
     if (tm1) tm = tm1;
-    if (Getattr(tm,k_code)) {
+    if (Getattr(tm,"code")) {
       *(nmatch) = *nmatch + 1;
     } else {
       tm = 0;
@@ -766,7 +750,7 @@ static
 void replace_local_types(ParmList *p, const String *name, const String *rep) {
   SwigType *t;
   while (p) {
-    t = Getattr(p,k_type);
+    t = Getattr(p,"type");
     Replace(t,name,rep,DOH_REPLACE_ANY);
     p = nextSibling(p);
   }
@@ -799,7 +783,7 @@ void typemap_replace_vars(String *s, ParmList *locals, SwigType *type, SwigType
     int  rep = 0;
     p = locals;
     while (p) {
-      if (Strchr(Getattr(p,k_type),'$')) rep = 1;
+      if (Strchr(Getattr(p,"type"),'$')) rep = 1;
       p = nextSibling(p);
     }
     if (!rep) locals = 0;
@@ -817,7 +801,7 @@ void typemap_replace_vars(String *s, ParmList *locals, SwigType *type, SwigType
     int i;
     if (SwigType_array_ndim(type) != SwigType_array_ndim(ftype)) type = ftype;
     ndim = SwigType_array_ndim(type);
-    size = NewStringEmpty();
+    size = NewString("");
     for (i = 0; i < ndim; i++) {
       String *dim = SwigType_array_getdim(type,i);
       if (index == 1) {
@@ -1083,19 +1067,19 @@ static void typemap_locals(DOHString *s, ParmList *l, Wrapper *f, int argnum) {
 
   p = l;
   while (p) {
-    SwigType *pt = Getattr(p,k_type);
+    SwigType *pt = Getattr(p,"type");
     SwigType *at = SwigType_alttype(pt, 1);
-    String   *pn = Getattr(p,k_name);
-    String   *value = Getattr(p,k_value);
+    String   *pn = Getattr(p,"name");
+    String   *value = Getattr(p,"value");
     if (at) pt = at;
     if (pn) {
       if (Len(pn) > 0) {
 	String *str;
 	int     isglobal = 0;
 
-	str = NewStringEmpty();
+	str = NewString("");
 
-	if (strncmp(Char(pn),"_global_",8) == 0) {
+	if (Strncmp(pn,"_global_",8) == 0) {
 	    isglobal = 1;
 	}
 
@@ -1105,12 +1089,10 @@ static void typemap_locals(DOHString *s, ParmList *l, Wrapper *f, int argnum) {
 	if ((argnum >= 0) && (!isglobal)) {
 	  Printf(str,"%s%d",pn,argnum);
 	} else {
-	  StringAppend(str,pn);
+	  Printf(str,"%s",pn);
 	}
 	if (isglobal && Wrapper_check_local(f,str)) {
 	    p = nextSibling(p);
-	    Delete(str);
-	    if (at) Delete(at);
 	    continue;
 	}
 	if (value) {
@@ -1130,7 +1112,7 @@ static void typemap_locals(DOHString *s, ParmList *l, Wrapper *f, int argnum) {
       }
     }
     p = nextSibling(p);
-    if (at) Delete(at);
+    Delete(at);
   }
 }
 
@@ -1151,22 +1133,15 @@ String *Swig_typemap_lookup(const String_or_char *op, SwigType *type, String_or_
   tm = Swig_typemap_search(op,type,pname,&mtype);
   if (!tm) return 0;
 
-  s = Getattr(tm,k_code);
-  if (!s) {
-    if (mtype) Delete(mtype);
-    return 0;
-  }
-  
+  s = Getattr(tm,"code");
+  if (!s) return 0;
 
   /* Blocked */
-  if (Cmp(s,"pass") == 0) {
-    Delete(mtype);
-    return 0;
-  }
+  if (Cmp(s,"pass") == 0) return 0;
 
   s = Copy(s);             /* Make a local copy of the typemap code */
 
-  locals = Getattr(tm,k_locals);
+  locals = Getattr(tm,"locals");
   if (locals) locals = CopyParmList(locals);
 
   /* This is wrong.  It replaces locals in place.   Need to fix this */
@@ -1224,46 +1199,61 @@ String *Swig_typemap_lookup_new(const String_or_char *op, Node *node, const Stri
   String   *symname;
   String   *cname = 0;
   String   *clname = 0;
-  char     *cop = Char(op);
+#if 0
+  String   *qsn;
+  Symtab   *st;
+#endif
   /* special case, we need to check for 'ref' call 
      and set the default code 'sdef' */
   if (Cmp(op,"newfree") == 0) { 
     sdef = Swig_ref_call(node, lname);
   }
 
-  type  = Getattr(node,k_type);
+  type  = Getattr(node,"type");
   if (!type) return sdef;
 
-  pname = Getattr(node,k_name);
+  pname = Getattr(node,"name");
 
-#if 1
-  if (pname && node && checkAttribute(node,k_kind,"function")) {
-    /* 
-       For functions, look qualified names first, such as
+#if 0
+  /* removed for now as it breaks old code and introduces
+  inconsistencies and adds about 25% to the execution time of the
+  test-suite - WSF This is my plan to fix this longer term: The
+  following debug shows that some typemap lookups use fully qualified
+  names and some do not.
+
+Printf(stdout, "Swig_typemap_lookup %s [%s %s]\n", op, type, pname ? pname : "NONAME");
+
+  So even the current typemap lookups are inconsistent.  The "name"
+  attribute is often changed, particularly in lang.cxx. I hope to
+  either remove this name changing to fix this or introduce a new
+  attribute to use for the name.  Possibly introduce a new attribute
+  called fqname - fully qualified name, that holds the name to use for
+  the Swig_typemap_search.  If this typemap search fails then use the
+  unqualified name.  Need to check non-simple return types, eg
+  pointers/references.
+  */
+  st = Getattr(node,"sym:symtab");
+  qsn = st ? Swig_symbol_qualifiedscopename(st) : 0;
+  if (qsn && Len(qsn)) {
+    /* look qualified names first, such as
        
-       struct Foo {
-          int *foo(int bar)   ->  Foo::foo
-       };
+         int *Foo::foo(int bar)   ->  Foo::foo
     */
-    Symtab *st = Getattr(node,k_symsymtab);
-    String *qsn = st ? Swig_symbol_string_qualify(pname, st) : 0;
-    if (qsn) {
-      if (StringLen(qsn) && !Equal(qsn,pname)) {
-	tm = Swig_typemap_search(op,type,qsn,&mtype);
-	if (tm && (!Getattr(tm,k_pname) || 
-		   strstr(Char(Getattr(tm,k_type)),"SWIGTYPE"))) {
-	  tm = 0;
-	}
-      }
-      Delete(qsn);
-    }
+    String *qname = NewStringf("%s::%s",qsn,pname);
+    tm = Swig_typemap_search(op,type,qname,&mtype);
+    Delete(qname);
   }
+  Delete(qsn);
+  
+  /* look now for simple name, such as
+       int *Foo::foo(int bar)   ->  foo
+  */
   if (!tm)
 #endif
   tm = Swig_typemap_search(op,type,pname,&mtype);
   if (!tm) return sdef;
 
-  s = Getattr(tm,k_code);
+  s = Getattr(tm,"code");
   if (!s) return sdef;
 
   /* Empty typemap. No match */
@@ -1271,7 +1261,7 @@ String *Swig_typemap_lookup_new(const String_or_char *op, Node *node, const Stri
 
   s = Copy(s);             /* Make a local copy of the typemap code */
 
-  locals = Getattr(tm,k_locals);
+  locals = Getattr(tm,"locals");
   if (locals) locals = CopyParmList(locals);
 
   if (pname) {
@@ -1302,44 +1292,44 @@ String *Swig_typemap_lookup_new(const String_or_char *op, Node *node, const Stri
 
   Replace(s,"$name",pname,DOH_REPLACE_ANY);
   
-  symname = Getattr(node,k_symname);
+  symname = Getattr(node,"sym:name");
   if (symname) {
     Replace(s,"$symname",symname, DOH_REPLACE_ANY);
   }
 
   Setattr(node,tmop_name(op),s);
   if (locals) {
-    sprintf(temp,"%s:locals", cop);
+    sprintf(temp,"%s:locals", Char(op));
     Setattr(node,tmop_name(temp), locals);
     Delete(locals);  
   }
 
-  if (HashCheckAttr(tm,k_type,k_SWIGTYPE)) {
-    sprintf(temp,"%s:SWIGTYPE", cop);
-    Setattr(node,tmop_name(temp),k_1);
+  if (checkAttribute(tm,"type","SWIGTYPE")) {
+    sprintf(temp,"%s:SWIGTYPE", Char(op));
+    Setattr(node,tmop_name(temp),"1");
   }
 
   /* Attach kwargs */
-  kw = Getattr(tm,k_kwargs);
+  kw = Getattr(tm,"kwargs");
   while (kw) {
-    String *value = Copy(Getattr(kw,k_value));
-    String *type = Getattr(kw,k_type);
-    char *ckwname = Char(Getattr(kw,k_name));
-    if (type) {      
-      String *mangle = Swig_string_mangle(type);
-      StringAppend(value,mangle);
+    String *value = Copy(Getattr(kw,"value"));
+    String *type = Getattr(kw,"type");
+    if (type) {
+      SwigType *rtype = SwigType_typedef_resolve_all(type);
+      String *mangle = Swig_string_mangle(rtype);
+      Printf(value,"%s",mangle);
       Delete(mangle);
+      Delete(rtype);
     }
-    sprintf(temp,"%s:%s",cop, ckwname);
+    sprintf(temp,"%s:%s",Char(op),Char(Getattr(kw,"name")));
     Setattr(node,tmop_name(temp), value);
-    Delete(value);
     kw = nextSibling(kw);
   }
 
   /* Look for warnings */
   {
     String *w;
-    sprintf(temp,"%s:warning", cop);
+    sprintf(temp,"%s:warning", Char(op));
     w = Getattr(node,tmop_name(temp));
     if (w) {
       Swig_warning(0,Getfile(node),Getline(node),"%s\n", w);
@@ -1349,14 +1339,10 @@ String *Swig_typemap_lookup_new(const String_or_char *op, Node *node, const Stri
   /* Look for code fragments */
   {
     String *f;
-    sprintf(temp,"%s:fragment", cop);
+    sprintf(temp,"%s:fragment", Char(op));
     f = Getattr(node,tmop_name(temp));
     if (f) {
-      String *fname = Copy(f);
-      Setfile(fname, Getfile(node));
-      Setline(fname, Getline(node));
-      Swig_fragment_emit(fname);
-      Delete(fname);
+      Swig_fragment_emit(f);
     }
   }
     
@@ -1385,27 +1371,22 @@ String *Swig_typemap_lookup_new(const String_or_char *op, Node *node, const Stri
 
 void
 Swig_typemap_attach_kwargs(Hash *tm, const String_or_char *op, Parm *p) {
-  String *temp = NewStringEmpty();
-  Parm *kw = Getattr(tm,k_kwargs);
+  String *temp = NewString("");
+  Parm *kw = Getattr(tm,"kwargs");
   while (kw) {
-    String *value = Copy(Getattr(kw,k_value));
-    String *type = Getattr(kw,k_type);
+    String *value = Copy(Getattr(kw,"value"));
+    String *type = Getattr(kw,"type");
     if (type) {
       Hash *v = NewHash();
-      Setattr(v,k_type,type);
-      Setattr(v,k_value,value);
-      Delete(value);
+      Setattr(v,"value",value);
+      Setattr(v,"type",type);
       value = v;
     }
     Clear(temp);
-    Printf(temp,"%s:%s",op,Getattr(kw,k_name));
+    Printf(temp,"%s:%s",op,Getattr(kw,"name"));
     Setattr(p,tmop_name(temp),value);
-    Delete(value);
     kw = nextSibling(kw);
   }
-  Clear(temp);
-  Printf(temp,"%s:match_type",op);
-  Setattr(p,tmop_name(temp),Getattr(tm,k_type));
   Delete(temp);
 }
 
@@ -1431,11 +1412,7 @@ Swig_typemap_emit_code_fragments(const String_or_char *op, Parm *p) {
   String *temp = NewStringf("%s:fragment",op);
   String *f = Getattr(p,tmop_name(temp));
   if (f) {
-    String *fname = Copy(f);
-    Setfile(fname, Getfile(p));
-    Setline(fname, Getline(p));
-    Swig_fragment_emit(fname);
-    Delete(fname);
+    Swig_fragment_emit(f);
   }
   Delete(temp);
 }
@@ -1447,20 +1424,6 @@ Swig_typemap_emit_code_fragments(const String_or_char *op, Parm *p) {
  * given typemap type
  * ----------------------------------------------------------------------------- */
 
-String *
-Swig_typemap_get_option(Hash *tm, String *name) 
-{
-  Parm *kw = Getattr(tm,k_kwargs);
-  while (kw) {
-    String *kname = Getattr(kw,k_name);
-    if (Equal(kname,name)) {
-      return Getattr(kw,k_value);
-    }
-    kw = nextSibling(kw);
-  }
-  return 0;
-}
-
 void
 Swig_typemap_attach_parms(const String_or_char *op, ParmList *parms, Wrapper *f) {
   Parm *p, *firstp;
@@ -1471,123 +1434,53 @@ Swig_typemap_attach_parms(const String_or_char *op, ParmList *parms, Wrapper *f)
   ParmList *locals;
   int   argnum = 0;
   char  temp[256];
-  char *cop = Char(op);
-  String *kwmatch = 0;
+
   p = parms;
-
-#ifdef SWIG_DEBUG
-    Printf(stdout,"Swig_typemap_attach_parms:  %s\n", op); 
-#endif
-
   while (p) {
     argnum++;
     nmatch = 0;
-#ifdef SWIG_DEBUG
-    Printf(stdout,"parms:  %s %s %s\n", op, Getattr(p,k_name), Getattr(p,k_type)); 
-#endif
     tm = Swig_typemap_search_multi(op,p,&nmatch);
-#ifdef SWIG_DEBUG
-    if (tm) Printf(stdout,"found:  %s\n", tm); 
-#endif
     if (!tm) {
       p = nextSibling(p);
       continue;
     }
-    /*
-      Check if the typemap requires to match the type of another
-      typemap, for example:
-
-        %typemap(in) SWIGTYPE * (int var) {...}
-	%typemap(freearg,match="in") SWIGTYPE * {if (var$argnum) ...}
-
-      here, the freearg typemap requires the "in" typemap to match,
-      or the 'var$argnum' variable will not exist.
-    */
-    kwmatch = Swig_typemap_get_option(tm,k_match);
-    if (kwmatch) {
-      String *tmname = NewStringf("tmap:%s",kwmatch);
-      String *tmin = Getattr(p,tmname);
-      Delete(tmname);
-#ifdef SWIG_DEBUG
-      if (tm) Printf(stdout,"matching:  %s\n", kwmatch); 
-#endif
-      if (tmin) {
-	String *tmninp = NewStringf("tmap:%s:numinputs",kwmatch);
-	String *ninp = Getattr(p,tmninp);
-	Delete(tmninp);
-	if (ninp && Equal(ninp, "0")) {
-	  p = nextSibling(p);
-	  continue;
-	} else {
-	  SwigType *typetm = Getattr(tm,k_type);
-	  String *temp = NewStringf("tmap:%s:match_type",kwmatch);
-	  SwigType *typein = Getattr(p,temp);
-	  Delete(temp);
-	  if (!Equal(typein,typetm)) {
-	    p = nextSibling(p);
-	    continue;
-	  } else {
-	    int nnmatch;
-	    Hash *tmapin = Swig_typemap_search_multi(kwmatch,p,&nnmatch);
-	    String *tmname = Getattr(tm,k_pname);
-	    String *tnname = Getattr(tmapin,k_pname);
-	    if (!(tmname && tnname && Equal(tmname, tnname)) && !(!tmname && !tnname)) {
-	      p = nextSibling(p);
-	      continue;
-	    }
-	  }
-	  
-	}
-      } else {
-	p = nextSibling(p);
-	continue;
-      }
-    }
-    
-    s = Getattr(tm,k_code);
+    s = Getattr(tm,"code");
     if (!s) {
       p = nextSibling(p);
       continue;
     }
-#ifdef SWIG_DEBUG
-    if (s) Printf(stdout,"code:  %s\n", s); 
-#endif
-    
+
     /* Empty typemap. No match */
     if (Cmp(s,"pass") == 0) {
       p = nextSibling(p);
       continue;
     }
-    
+
     s = Copy(s);
-    locals = Getattr(tm,k_locals);
+    locals = Getattr(tm,"locals");
     if (locals) locals = CopyParmList(locals);
     firstp = p;
-#ifdef SWIG_DEBUG
-    Printf(stdout,"nmatch:  %d\n", nmatch); 
-#endif
     for (i = 0; i < nmatch; i++) {
       SwigType *type;
       String   *pname;
       String   *lname;
       SwigType *mtype;
 
-
-      type = Getattr(p,k_type);
-      pname = Getattr(p,k_name);
-      lname = Getattr(p,k_lname);
-      mtype = Getattr(p,k_tmapmatch);
+      type = Getattr(p,"type");
+      pname = Getattr(p,"name");
+      lname = Getattr(p,"lname");
+      mtype = Getattr(p,"tmap:match");
 
       if (mtype) {
 	typemap_replace_vars(s,locals,mtype,type,pname,lname,i+1);
-	Delattr(p,k_tmapmatch);
+	Delattr(p,"tmap:match");
       } else {
 	typemap_replace_vars(s,locals,type,type,pname,lname,i+1);
       }
 
-      if (HashCheckAttr(tm,k_type,k_SWIGTYPE)) {
-	sprintf(temp,"%s:SWIGTYPE", cop);
-	Setattr(p,tmop_name(temp),k_1);
+      if (checkAttribute(tm,"type","SWIGTYPE")) {
+	sprintf(temp,"%s:SWIGTYPE", Char(op));
+	Setattr(p,tmop_name(temp),"1");
       }
       p = nextSibling(p);
     }
@@ -1603,19 +1496,16 @@ Swig_typemap_attach_parms(const String_or_char *op, ParmList *parms, Wrapper *f)
     Replace(s,"$argnum",temp, DOH_REPLACE_ANY);
 
     /* Attach attributes to object */
-#ifdef SWIG_DEBUG
-    Printf(stdout,"attach: %s %s %s\n", Getattr(firstp,k_name), tmop_name(op), s); 
-#endif
     Setattr(firstp,tmop_name(op),s);           /* Code object */
 
     if (locals) {
-      sprintf(temp,"%s:locals", cop);
+      sprintf(temp,"%s:locals", Char(op));
       Setattr(firstp,tmop_name(temp), locals);
       Delete(locals);
     }
 
     /* Attach a link to the next parameter.  Needed for multimaps */
-    sprintf(temp,"%s:next",cop);
+    sprintf(temp,"%s:next",Char(op));
     Setattr(firstp,tmop_name(temp),p);
 
     /* Attach kwargs */
@@ -1629,16 +1519,7 @@ Swig_typemap_attach_parms(const String_or_char *op, ParmList *parms, Wrapper *f)
 
     /* increase argnum to consider numinputs */
     argnum += nmatch - 1;
-    Delete(s);
-#ifdef SWIG_DEBUG
-    Printf(stdout,"res: %s %s %s\n", Getattr(firstp,k_name), tmop_name(op), Getattr(firstp,tmop_name(op))); 
-#endif
-
   }
-#ifdef SWIG_DEBUG
-  Printf(stdout,"Swig_typemap_attach_parms: end\n"); 
-#endif
-
 }
 
 /* -----------------------------------------------------------------------------
@@ -1664,7 +1545,7 @@ static List *split_embedded(String *s) {
   int  leading = 1;
   args = NewList();
   
-  c = strstr(Char(s),"(");
+  c = Strstr(s,"(");
   c++;
 
   start = c;
@@ -1703,7 +1584,7 @@ static void split_var(String *s, String **name, String **value) {
   char *eq;
   char *c;
 
-  eq = strstr(Char(s),"=");
+  eq = Strstr(s,"=");
   if (!eq) {
     *name = 0;
     *value = 0;
@@ -1727,13 +1608,13 @@ static void split_var(String *s, String **name, String **value) {
 }
 
 static void replace_embedded_typemap(String *s) {
-  char *start = 0;
-  while ((start = strstr(Char(s),"$TYPEMAP("))) {
+  while (Strstr(s,"$TYPEMAP(")) {
 
     /* Gather the argument */
-    char *end=0,*c;
+    char *start, *end=0,*c;
     int  level = 0;
     String *tmp;
+    start = Strstr(s,"$TYPEMAP(");
     c = start;
     while (*c) {
       if (*c == '(') level++;
@@ -1757,20 +1638,17 @@ static void replace_embedded_typemap(String *s) {
       List   *l;
       Hash   *vars;
       String *method;
-      int i, ilen;
+      int i;
 
       l = split_embedded(tmp);
       vars = NewHash();
-      ilen = Len(l);
-      for (i = 1; i < ilen; i++) {
+      for (i = 1; i < Len(l); i++) {
 	String *n, *v;
 	split_var(Getitem(l,i),&n,&v);
 	if (n && v) {
 	  Insert(n,0,"$");
 	  Setattr(vars,n,v);
 	}
-	Delete(n);
-	Delete(v);
       }
 
       method = Getitem(l,0);
@@ -1791,9 +1669,9 @@ static void replace_embedded_typemap(String *s) {
 	      set_previousSibling(v,p);
 	    }
 	    p = v;
-	    Setattr(p,k_lname,Getattr(p,k_name));
-	    if (Getattr(p,k_value)) {
-	      Setattr(p,k_name,Getattr(p,k_value));
+	    Setattr(p,"lname",Getattr(p,"name"));
+	    if (Getattr(p,"value")) {
+	      Setattr(p,"name",Getattr(p,"value"));
 	    }
 	    if (!first) first = p;
 	    DohIncref(p);
@@ -1805,9 +1683,6 @@ static void replace_embedded_typemap(String *s) {
 	}
 	/* Perform a typemap search */
 	if (first) {
-#ifdef SWIG_DEBUG
-	  Printf(stdout,"Swig_typemap_attach_parms:  embedded\n"); 
-#endif	  
 	  Swig_typemap_attach_parms(method,first,0);
 	  {
 	    String *tm;
